/*
// File:		ImapMessageData.cpp
//
// Version:		mail.it library 1.0 sample file
//
// Copyright:	(C) 2007 Dacons LLP.
//
// Bugs:		If you have problems or suggestions, please contact
//				the Online Support at: http://www.dacons.net/support
*/

#include PCH_FILE_NAME
#include "ImapMessageData.hpp"
#include <iostream>


ImapMessageData::ImapMessageData():
	mMessage(NULL, false),
	mFlags(0),
	mUid(0),
	mFullMessageData(false)
{
}

ImapMessageData::ImapMessageData(const EmaiUint32 inUID):
	mMessage(NULL, false),
	mFlags(0),
	mUid(inUID),
	mFullMessageData(false)
{
}

ImapMessageData::~ImapMessageData()
{
}

void
ImapMessageData::SetData(
		const EmaiFetchResponse& inResponse)
{
	if (inResponse.flags.flags != 0)
		mFlags = inResponse.flags.flags;

	if (inResponse.uid != 0)
		mUid = inResponse.uid;

	if (inResponse.rfc822.data != NULL)
	{
		mMessage = Emai::Message(inResponse.rfc822.data, inResponse.rfc822.dataLength, EmaiNullOptions);
		mFullMessageData = true;
	}
	else
	{
		if (!HasFullMessageData())
		{
			if ((inResponse.rfc822Header.data != NULL) && (inResponse.rfc822Text.data != NULL))
			{
				EmaiChar* body = new EmaiChar[inResponse.rfc822Header.dataLength + inResponse.rfc822Text.dataLength];
				::memcpy(body, inResponse.rfc822Header.data, inResponse.rfc822Header.dataLength);
				::memcpy(body + inResponse.rfc822Header.dataLength, inResponse.rfc822Text.data, 
					inResponse.rfc822Text.dataLength);
				mMessage = Emai::Message(body, inResponse.rfc822Header.dataLength + inResponse.rfc822Text.dataLength,
					EmaiNullOptions);
				delete[] body;
				mFullMessageData = true;
			}
			else if (inResponse.rfc822Header.data != NULL)
			{
				mMessage = Emai::Message(inResponse.rfc822Header.data, inResponse.rfc822Header.dataLength, EmaiNullOptions);
			}
			else if (inResponse.rfc822Text.data != NULL)
			{
				if (mMessage != NULL)
				{
					const void* data = NULL;
					EmaiUint32 headerSize = 0;
					mMessage.GetData(&data, &headerSize, NULL);
					EmaiUint32 bodySize = headerSize + inResponse.rfc822Text.dataLength;
					EmaiChar* body = new EmaiChar[bodySize];
					::memcpy(body, data, headerSize);
					::memcpy(body + headerSize, inResponse.rfc822Text.data, inResponse.rfc822Text.dataLength);
					mMessage = Emai::Message(body, bodySize, EmaiNullOptions);
					delete[] body;
					mFullMessageData = true;
				}
				else
					std::cout << "WARNING: Received text, but do not have header! Do nothing." << std::endl;
			}
		}
	}
}

bool
ImapMessageData::HasFullMessageData() const
{
	return mFullMessageData;
}


Emai::Message
ImapMessageData::GetMessage(
	) const
{
	return mMessage;
}

EmaiUint32 ImapMessageData::GetFlags() const
{
	return mFlags;
}

void ImapMessageData::SetFlags(EmaiUint32 inNewFlags)
{
	mFlags = inNewFlags;
}

EmaiUint32 ImapMessageData::GetUid() const
{
	return mUid;
}
