/*!
// @file		Pop3GUIDlg.hpp
//
// @brief		Dialog class
//
// @version		Mailit for C/C++ 1.0
//
// @author		(C) 2007 Dacons LLP.
//
// @bug			If you have problems or suggestions, please contact
//				the Online Support at: http://www.dacons.net/support
*/
#pragma once
#include "afxwin.h"
#include "afxcmn.h"

#include <EmaiMessage.hpp>
#include "MessagePartEnumerator.hpp"
#include <vector>

/*!
// @class	CPop3GUIDlg
// @brief	Pop3 sample dialog class.
*/
class CPop3GUIDlg : public CDialog
{
public:
	/*!
	// @brief	Standart constructor
	//
	// @param	pParent - pointer to parent window
	*/
	CPop3GUIDlg(CWnd* pParent = NULL);

	enum { IDD = IDD_POP3GUI_DIALOG };

	protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV support


// Implementation
protected:
	HICON m_hIcon;

	/*!
	// @brief	Initialize dialog function.
	//
	// @return	initialization result
	*/
	virtual BOOL OnInitDialog();

	/*!
	// @brief	Destroy dialog function. Calls before destructor.
	//
	*/
	afx_msg void OnPaint();
	afx_msg HCURSOR OnQueryDragIcon();
	afx_msg void OnDestroy();
	DECLARE_MESSAGE_MAP()

	/*!
	// @brief	Calls when user clicks on Receive button.
	*/
	afx_msg void OnBnClickedButtonReceive();

	/*!
	// @brief	Calls when user changes selection in message list.
	*/
	afx_msg void OnLvnItemchangedListMessages(NMHDR *pNMHDR, LRESULT *pResult);

	/*!
	// @brief	Calls when user clicks on plain text radio button.
	*/
	afx_msg void OnBnClickedRadioTextTypePlain();

	/*!
	// @brief	Calls when user clicks on html text radio button.
	*/
	afx_msg void OnBnClickedRadioTextTypeHtml();

	/*!
	// @brief	Calls when user clicks on check box.
	*/
	afx_msg void OnBnClickedCheckRemove();

	/*!
	// @brief	Calls when user clicks on Save button.
	*/
	afx_msg void OnBnClickedSave();

	/*!
	// @brief	Calls when user kills focus on licence textbox.
	*/
	afx_msg void OnEnKillfocusEditLickey();

	/*!
	// @brief	Calls when user sets focus on licence textbox.
	*/
	afx_msg void OnEnSetfocusEditLickey();

	CString mMailServer;
	CString mAccount;
	CString mPassword;
	CString mStatusText;
	CString mFromWho;
	CString mToWho;
	CString mMessageText;
	CString mCC;
	BOOL mTextType;
	BOOL mRemoveMessages;
	CComboBox mTimePeriods;
	CString mProgressPercent;
	UINT mPort;
	BOOL mUseSsl;
	CComboBox mAuthType;
	CListCtrl mMessagesList;
	CListCtrl mAttachmentsList;
	CString mLicenseKey;

private:
	std::vector<Emai::Message> mMessages;

	/*!
	// @brief	Returns formatted text string for message dialog's fields.
	//
	// @param	inFieldType - field type
	//
	// @param	inEnumerator - reference to enumerator class
	//
	// @return	string with formatted text
	*/
	CString FormatTextForTextField(EmaiOptions inFieldType, 
		MessagePartEnumerator& inEnumerator) const;

	/*!
	// @brief	Formats error messages.
	//
	// @param	inException - reference to exception class
	*/
	void FormatError(Emai::Exception& inException);

	/*!
	// @brief	Shows folder select dialog window for chosing folder.
	//
	// @return	string with path for saving
	*/
	void GetPath(EmaiConstUniCharPtr inDefaultFileName, Emai::UniString& outPath, Emai::UniString& outFileName);

	/*!
	// @brief	Free memory allocated for attachments list items.
	//
	*/
	void RemoveAllAttachments();
};
